@@ -42,6 +42,7 @@ class VaspErrorHandler(ErrorHandler, MSONable):
         "inv_rot_mat": ["inverse of rotation matrix was not found (increase "
                         "SYMPREC)"],
         "brmix": ["BRMIX: very serious problems"],
+        "rspher": ["ERROR RSPHER"],
         "subspacematrix": ["WARNING: Sub-Space-Matrix is not hermitian in DAV"],
         "tetirr": ["Routine TETIRR needs special values"],
         "incorrect_shift": ["Could not get correct shifts"],
@@ -77,7 +78,7 @@ class VaspErrorHandler(ErrorHandler, MSONable):
         if "brmix" in self.errors:
             actions.append({'dict': 'INCAR',
                             'action': {'_set': {'IMIX': 1}}})
-        if "subspacematrix" in self.errors:
+        if "subspacematrix" in self.errors or "rspher" in self.errors:
             actions.append({'dict': 'INCAR',
                             'action': {'_set': {'INCAR->LREAL': False}}})
         if "tetirr" in self.errors or "incorrect_shift" in self.errors:
@@ -91,11 +92,12 @@ class VaspErrorHandler(ErrorHandler, MSONable):
             actions.append({'dict': 'KPOINTS',
                             'action': {'_set': {'kpoints': [[m] * 3]}}})
         m = Modder()
+        modified = []
         for a in actions:
+            modified.append(a["dict"])
             vi[a["dict"]] = m.modify_object(a["action"], vi[a["dict"]])
-        vi["INCAR"].write_file("INCAR")
-        vi["POSCAR"].write_file("POSCAR")
-        vi["KPOINTS"].write_file("KPOINTS")
+        for f in modified:
+            vi[f].write_file(f)
         return {"errors": list(self.errors), "actions": actions}
 
     def __str__(self):
